@@ -28,7 +28,7 @@ Here is a minimal deployable pattern definition:
 
 Typescript
 
-```typescript
+```python
 import { Construct } from 'constructs';
 import { Stack, StackProps } from 'aws-cdk-lib';
 import { ApiGatewayToLambda } from '@aws-solutions-constructs/aws-apigateway-lambda';
@@ -141,6 +141,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_apigateway
@@ -166,8 +168,8 @@ class ApiGatewayToLambda(
         *,
         api_gateway_props: typing.Any = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -181,6 +183,10 @@ class ApiGatewayToLambda(
         :since: 0.8.0
         :summary: Constructs a new instance of the ApiGatewayToLambda class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ApiGatewayToLambda.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApiGatewayToLambdaProps(
             api_gateway_props=api_gateway_props,
             existing_lambda_obj=existing_lambda_obj,
@@ -227,8 +233,8 @@ class ApiGatewayToLambdaProps:
         *,
         api_gateway_props: typing.Any = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''The properties for the ApiGatewayToLambda class.
 
@@ -241,6 +247,12 @@ class ApiGatewayToLambdaProps:
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(ApiGatewayToLambdaProps.__init__)
+            check_type(argname="argument api_gateway_props", value=api_gateway_props, expected_type=type_hints["api_gateway_props"])
+            check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
+            check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
+            check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
         self._values: typing.Dict[str, typing.Any] = {}
         if api_gateway_props is not None:
             self._values["api_gateway_props"] = api_gateway_props
